package com.jiuqi.db.impl;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.jiuqi.db.DBFunction;
import com.jiuqi.db.DBMetaData;
import com.jiuqi.db.impl.SQLServerDBFunction;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;
import java.util.List;

public class SQLServerDBMetaData implements DBMetaData {
  private static final String LeftParenthesis = "(";
  
  private static final String RightParenthesis = ")";
  
  private static final String comma = ",";
  
  private static final String IsNull = "null";
  
  private static final String NotNull = "not null";
  
  private static final String space = " ";
  
  private static final String DEF = " default ";
  
  private static final String BIT = "bit";
  
  private static final String TINYINT = "tinyint";
  
  private static final String SMALLINT = "smallint";
  
  private static final String INTEGER = "int";
  
  private static final String BIGINT = "bigint";
  
  private static final String FLOAT = "float";
  
  private static final String REAL = "real";
  
  private static final String DOUBLE = "float";
  
  private static final String NUMERIC = "numeric";
  
  private static final String DECIMAL = "decimal";
  
  private static final String CHAR = "char";
  
  private static final String VARCHAR = "varchar";
  
  private static final String LONGVARCHAR = "text";
  
  private static final String TIMESTAMP = "datetime";
  
  private static final String VARBINARY = "varbinary";
  
  private static final String LONGVARBINARY = "image";
  
  private static final String BLOB = "image";
  
  private static final String CLOB = "text";
  
  private int maxColumnCount;
  
  private int maxRecordSize;
  
  private void raise(String msg) throws SQLException {
    throw new SQLException(msg);
  }
  
  public SQLServerDBMetaData(DatabaseMetaData metaData) throws SQLException {
    this.maxColumnCount = metaData.getMaxColumnsInTable();
    this.maxRecordSize = metaData.getMaxRowSize();
  }
  
  public int databaseType() {
    return 1;
  }
  
  public int maxColumnCount() {
    return this.maxColumnCount;
  }
  
  public int maxRecordSize() {
    return this.maxRecordSize;
  }
  
  public int maxIndexNameLength() {
    return 64;
  }
  
  public int maxFieldNameLength() {
    return 64;
  }
  
  public int maxTableNameLength() {
    return 64;
  }
  
  public int maxColumnByteSize(int sqlType) throws SQLException {
    int result = 0;
    switch (sqlType) {
      case -7:
        result = 1;
        break;
      case -6:
        result = 1;
        break;
      case 5:
        result = 2;
        break;
      case 4:
        result = 4;
        break;
      case -5:
        result = 8;
        break;
      case 6:
        result = 8;
        break;
      case 7:
        result = 4;
        break;
      case 2:
        result = 17;
        break;
      case 3:
        result = 17;
        break;
      case 1:
        result = -1;
        break;
      case 12:
        result = -1;
        break;
      case -1:
        result = 16;
        break;
      case 93:
        result = 8;
        break;
      case -2:
        result = -1;
        break;
      case -3:
        result = -1;
        break;
      case -4:
        result = 16;
        break;
      case 2004:
        result = 16;
        break;
      case 2005:
        result = 16;
        break;
    } 
    if (result == 0)
      raise("不支持的数据类型 " + Integer.toString(sqlType)); 
    return result;
  }
  
  public String getFieldDDL(int sqlType, int size, int scale, boolean isNull, String defValue) throws SQLException {
    StringBuffer result = new StringBuffer();
    switch (sqlType) {
      case -7:
        result.append("bit");
        break;
      case -6:
        result.append("tinyint");
        break;
      case 5:
        result.append("smallint");
        break;
      case 4:
        result.append("int");
        break;
      case -5:
        result.append("bigint");
        break;
      case 6:
        result.append("float");
        break;
      case 7:
        result.append("real");
        break;
      case 8:
        result.append("float");
        break;
      case 2:
        if (size < 0 || size > 38 || scale < 0 || scale > 38)
          raise("精度或小数位定义错误 精度:" + size + "小数位:" + scale); 
        result.append("numeric");
        result.append("(");
        result.append(size);
        result.append(",");
        result.append(scale);
        result.append(")");
        break;
      case 3:
        if (size < 0 || size > 38 || scale < 0 || scale > 38)
          raise("精度或小数位定义错误 精度:" + size + "小数位:" + scale); 
        result.append("decimal");
        result.append("(");
        result.append(size);
        result.append(",");
        result.append(scale);
        result.append(")");
        break;
      case 1:
        if (size > 8000 || size <= 0)
          raise("长度定义错误应在1~8000之间"); 
        result.append("char");
        result.append("(");
        result.append(size);
        result.append(")");
        break;
      case 12:
        if (size > 8000 || size <= 0)
          raise("长度定义错误应在1~8000之间"); 
        result.append("varchar");
        result.append("(");
        result.append(size);
        result.append(")");
        break;
      case -1:
        result.append("text");
        break;
      case 91:
      case 92:
      case 93:
        result.append("datetime");
        break;
      case -3:
      case -2:
        if (size > 8000 || size <= 0)
          raise("长度定义错误应在1~8000之间"); 
        result.append("varbinary");
        result.append("(");
        result.append(size);
        result.append(")");
        break;
      case -4:
        result.append("image");
        break;
      case 2004:
        result.append("image");
        break;
      case 2005:
        result.append("text");
        break;
    } 
    if (result.length() == 0)
      raise("不支持的数据类型"); 
    result.append(" ");
    result.append(isNull ? "null" : "not null");
    result.append(" ");
    if (defValue != null && !defValue.equals("")) {
      result.append(" default ");
      result.append(defValue);
    } 
    return result.toString();
  }
  
  public String getDropFieldPreSql(String tableName, String fieldName) {
    return null;
  }
  
  public String getDropFieldDDL(String tableName, String fieldName) {
    return "alter table " + tableName + " drop column " + fieldName;
  }
  
  public boolean getModifyFieldSqls(String tableName, String sFieldName, int sSqlType, int sSize, int sScale, boolean sIsNull, String sDefValue, String dFieldName, int dSqlType, int dSize, int dScale, boolean dIsNull, String dDefValue, List<String> sqls) throws SQLException {
    StringBuffer sql = new StringBuffer();
    if (sFieldName.equals(dFieldName)) {
      sql.append("alter table ");
      sql.append(tableName);
      sql.append(" alter column ");
      sql.append(sFieldName);
      sql.append(" ");
      sql.append(getFieldDDL(dSqlType, dSize, dScale, dIsNull, dDefValue));
      sqls.add(sql.toString());
      return true;
    } 
    return false;
  }
  
  public boolean getDDLCausesTransactionCommit() {
    return false;
  }
  
  public boolean getDDLIgnoredInTransactions() {
    return false;
  }
  
  public String getDefaultScheme() {
    return null;
  }
  
  public boolean getSupportDropColumn() {
    return true;
  }
  
  public DBFunction createDBFunction() {
    return (DBFunction)new SQLServerDBFunction();
  }
  
  public boolean getTruncateNumber() {
    return false;
  }
}
